@@ -1,12 +1,12 @@
 /**
  * @file feed_parser.c  parsing of different feed formats
- * 
+ *
  * Copyright (C) 2008-2017 Lars Windolf <lars.windolf@gmx.de>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version. 
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
- 
+
 #include <string.h>
 
 #include "common.h"
@@ -25,10 +25,11 @@
 #include "html.h"
 #include "metadata.h"
 #include "xml.h"
-#include "parsers/cdf_channel.h"
-#include "parsers/rss_channel.h"
 #include "parsers/atom10.h"
+#include "parsers/cdf_channel.h"
+#include "parsers/html5_feed.h"
 #include "parsers/pie_feed.h"
+#include "parsers/rss_channel.h"
 
 static GSList *feedHandlers = NULL;	/**< list of available parser implementations */
 
@@ -42,12 +43,14 @@ feed_parsers_get_list (void)
 {
 	if (feedHandlers)
 		return feedHandlers;
-	
+
 	feedHandlers = g_slist_append (feedHandlers, rss_init_feed_handler ());
 	feedHandlers = g_slist_append (feedHandlers, cdf_init_feed_handler ());
 	feedHandlers = g_slist_append (feedHandlers, atom10_init_feed_handler ());  /* Must be before pie */
 	feedHandlers = g_slist_append (feedHandlers, pie_init_feed_handler ());
-	
+
+	// Do not register HTML5 feed parser here, as it is a HTML parser
+
 	return feedHandlers;
 }
 
@@ -64,10 +67,10 @@ feed_type_str_to_fhp (const gchar *str)
 {
 	GSList *iter;
 	feedHandlerPtr fhp = NULL;
-	
+
 	if (!str)
 		return NULL;
-		
+
 	if (strstr(str, "pie"))
 		return feed_type_str_to_fhp ("atom");
 
@@ -106,19 +109,21 @@ feed_free_parser_ctxt (feedParserCtxtPtr ctxt)
  * tries to download it. If it finds a valid feed source it parses
  * this source instead into the given feed parsing context. It also
  * replaces the HTTP URI with the found feed source.
+ *
+ * Mutates ctxt->failed and ctxt->feed->parseErrors
  */
-static void
+static gboolean
 feed_parser_auto_discover (feedParserCtxtPtr ctxt)
 {
-	gchar	*source;
-	
+	gchar		*source;
+
 	if (ctxt->feed->parseErrors)
 		g_string_truncate (ctxt->feed->parseErrors, 0);
 	else
 		ctxt->feed->parseErrors = g_string_new(NULL);
-		
+
 	debug1 (DEBUG_UPDATE, "Starting feed auto discovery (%s)", subscription_get_source (ctxt->subscription));
-	
+
 	source = html_auto_discover_feed (ctxt->data, subscription_get_source (ctxt->subscription));
 
 	/* FIXME: we only need the !g_str_equal as a workaround after a 404 */
@@ -138,13 +143,32 @@ feed_parser_auto_discover (feedParserCtxtPtr ctxt)
 	}
 }
 
+static void
+feed_parser_ctxt_cleanup (feedParserCtxtPtr ctxt)
+{
+	/* free old temp. parsing data, don't free right after parsing because
+	it can be used until the last feed request is finished, move me
+	to the place where the last request in list otherRequests is
+	finished :-) */
+	g_hash_table_destroy (ctxt->tmpdata);
+	ctxt->tmpdata = g_hash_table_new_full (g_str_hash, g_str_equal, NULL, g_free);
+
+	/* we always drop old metadata */
+	metadata_list_free (ctxt->subscription->metadata);
+
+	ctxt->subscription->metadata = NULL;
+	ctxt->failed = FALSE;
+}
+
 /**
  * General feed source parsing function. Parses the passed feed source
- * and tries to determine the source type. 
+ * and tries to determine the source type. If all feed handlers fail
+ * tries to do HTML5 feed extraction. If this also fails starts feed
+ * link auto-discovery.
  *
  * @param ctxt		feed parsing context
  *
- * @returns FALSE if auto discovery is indicated, 
+ * @returns FALSE if auto discovery is indicated,
  *          TRUE if feed type was recognized and parsing was successful
  */
 gboolean
@@ -153,37 +177,37 @@ feed_parse (feedParserCtxtPtr ctxt)
 	xmlNodePtr	cur;
 	gboolean	success = FALSE;
 
-	debug_enter("feed_parse");
+	debug_enter ("feed_parse");
+
+	g_assert (NULL == ctxt->items);
 
-	g_assert(NULL == ctxt->items);
-	
 	ctxt->failed = TRUE;	/* reset on success ... */
 
-	if(ctxt->feed->parseErrors)
-		g_string_truncate(ctxt->feed->parseErrors, 0);
+	if (ctxt->feed->parseErrors)
+		g_string_truncate (ctxt->feed->parseErrors, 0);
 	else
-		ctxt->feed->parseErrors = g_string_new(NULL);
+		ctxt->feed->parseErrors = g_string_new (NULL);
 
-	/* try to parse buffer with XML and to create a DOM tree */	
+	/* 1.) try to parse downloaded data as XML and try to read a feed format */
 	do {
-		if(NULL == xml_parse_feed (ctxt)) {
+		if (NULL == xml_parse_feed (ctxt)) {
 			g_string_append_printf (ctxt->feed->parseErrors, _("XML error while reading feed! Feed \"%s\" could not be loaded!"), subscription_get_source (ctxt->subscription));
 			break;
 		}
-		
-		if(NULL == (cur = xmlDocGetRootElement(ctxt->doc))) {
+
+		if (NULL == (cur = xmlDocGetRootElement(ctxt->doc))) {
 			g_string_append(ctxt->feed->parseErrors, _("Empty document!"));
 			break;
 		}
-		
-		while(cur && xmlIsBlankNode(cur)) {
+
+		while (cur && xmlIsBlankNode(cur)) {
 			cur = cur->next;
 		}
-		
-		if(!cur)
+
+		if (!cur)
 			break;
-				
-		if(!cur->name) {
+
+		if (!cur->name) {
 			g_string_append(ctxt->feed->parseErrors, _("Invalid XML!"));
 			break;
 		}
@@ -193,53 +217,68 @@ feed_parse (feedParserCtxtPtr ctxt)
 		while(handlerIter) {
 			feedHandlerPtr handler = (feedHandlerPtr)(handlerIter->data);
 			if(handler && handler->checkFormat && (*(handler->checkFormat))(ctxt->doc, cur)) {
-				/* free old temp. parsing data, don't free right after parsing because
-				   it can be used until the last feed request is finished, move me 
-				   to the place where the last request in list otherRequests is 
-				   finished :-) */
-				g_hash_table_destroy(ctxt->tmpdata);
-				ctxt->tmpdata = g_hash_table_new_full(g_str_hash, g_str_equal, NULL, g_free);
-				
-				/* we always drop old metadata */
-				metadata_list_free(ctxt->subscription->metadata);
-				ctxt->subscription->metadata = NULL;
-				ctxt->failed = FALSE;
-
 				ctxt->feed->fhp = handler;
-				(*(handler->feedParser))(ctxt, cur);
-
+				feed_parser_ctxt_cleanup (ctxt);
+				(*(handler->feedParser)) (ctxt, cur);
 				break;
 			}
 			handlerIter = handlerIter->next;
 		}
 	} while(0);
-	
-	/* if the given URI isn't valid we need to start auto discovery */
-	if(ctxt->failed)
-		feed_parser_auto_discover (ctxt);
 
-	if(ctxt->failed) {
-		/* Autodiscovery failed */
-		/* test if we have a HTML page */
-		if((strstr(ctxt->data, "<html>") || strstr(ctxt->data, "<HTML>") ||
-		    strstr(ctxt->data, "<html ") || strstr(ctxt->data, "<HTML "))) {
-			debug0(DEBUG_UPDATE, "HTML document detected!");
-			g_string_append(ctxt->feed->parseErrors, _("Source points to HTML document."));
-		} else {
-			debug0(DEBUG_UPDATE, "neither a known feed type nor a HTML document!");
-			g_string_append(ctxt->feed->parseErrors, _("Could not determine the feed type."));
-		}
-	} else {
-		debug1(DEBUG_UPDATE, "discovered feed format: %s", feed_type_fhp_to_str(ctxt->feed->fhp));
-		success = TRUE;
-	}
-	
-	if(ctxt->doc) {
+	if (ctxt->doc) {
 		xmlFreeDoc(ctxt->doc);
 		ctxt->doc = NULL;
 	}
-		
-	debug_exit("feed_parse");
-	
+
+	/* 2.) None of the feed formats did work, chance is high that we are
+           working on a HTML documents. Let's look for feed links inside it! */
+	if (ctxt->failed)
+		feed_parser_auto_discover (ctxt);
+
+	/* 3.) alternatively try to parse the HTML document we are on as HTML5 feed */
+	if (ctxt->failed) {
+		do {
+			if (ctxt->doc = xhtml_parse (ctxt->data, ctxt->dataLength))
+				g_string_truncate (ctxt->feed->parseErrors, 0);
+			else
+				break;
+
+			if (NULL == (cur = xmlDocGetRootElement (ctxt->doc))) {
+				g_string_append(ctxt->feed->parseErrors, _("Empty document!"));
+				break;
+			}
+
+			ctxt->feed->fhp = html5_init_feed_handler ();
+			if ((*(ctxt->feed->fhp->checkFormat)) (ctxt->doc, cur)) {
+					feed_parser_ctxt_cleanup (ctxt);
+					(*(ctxt->feed->fhp->feedParser)) (ctxt, cur);
+			}
+		} while(0);
+	}
+
+	if (ctxt->doc) {
+		xmlFreeDoc(ctxt->doc);
+		ctxt->doc = NULL;
+	}
+
+	/* 4.) We give up and inform the user */
+	if (ctxt->failed) {
+		/* test if we have a HTML page */
+		if((strstr (ctxt->data, "<html>") || strstr (ctxt->data, "<HTML>") ||
+		    strstr (ctxt->data, "<html ") || strstr (ctxt->data, "<HTML "))) {
+			debug0(DEBUG_UPDATE, "HTML document detected!");
+			g_string_append (ctxt->feed->parseErrors, _("Source points to HTML document."));
+		} else {
+			debug0(DEBUG_UPDATE, "neither a known feed type nor a HTML document!");
+			g_string_append (ctxt->feed->parseErrors, _("Could not determine the feed type."));
+		}
+	} else {
+		debug1 (DEBUG_UPDATE, "discovered feed format: %s", feed_type_fhp_to_str(ctxt->feed->fhp));
+		success = TRUE;
+	}
+
+	debug_exit ("feed_parse");
+
 	return success;
 }
