@@ -1,8 +1,8 @@
 /*
  * @file feedlist.h  subscriptions as an hierarchic tree
  *
- * Copyright (C) 2005-2014 Lars Windolf <lars.windolf@gmx.de>
- *	      
+ * Copyright (C) 2005-2018 Lars Windolf <lars.windolf@gmx.de>
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -29,32 +29,8 @@
 
 G_BEGIN_DECLS
 
-#define FEEDLIST_TYPE		(feedlist_get_type ())
-#define FEEDLIST(obj)		(G_TYPE_CHECK_INSTANCE_CAST ((obj), FEEDLIST_TYPE, FeedList))
-#define FEEDLIST_CLASS(klass)	(G_TYPE_CHECK_CLASS_CAST ((klass), FEEDLIST_TYPE, FeedListClass))
-#define IS_FEEDLIST(obj)		(G_TYPE_CHECK_INSTANCE_TYPE ((obj), FEEDLIST_TYPE))
-#define IS_FEEDLIST_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE ((klass), FEEDLIST_TYPE))
-
-typedef struct FeedList		FeedList;
-typedef struct FeedListClass	FeedListClass;
-typedef struct FeedListPrivate	FeedListPrivate;
-
-extern FeedList *feedlist;
-
-struct FeedList
-{
-	GObject		parent;
-	
-	/*< private >*/
-	FeedListPrivate	*priv;
-};
-
-struct FeedListClass 
-{
-	GObjectClass parent_class;	
-};
-
-GType feedlist_get_type (void);
+#define FEED_LIST_TYPE (feedlist_get_type ())
+G_DECLARE_FINAL_TYPE (FeedList, feedlist, FEED, LIST, GObject)
 
 /**
  * feedlist_create: (skip)
@@ -63,12 +39,12 @@ GType feedlist_get_type (void);
  *
  * Returns: (transfer full): the feed list instance
  */
-FeedList * feedlist_create (void);
+FeedList * feedlist_create (gpointer feedListView);
 
 /**
  * feedlist_get_selected: (skip)
  *
- * Get currently selected feed list node 
+ * Get currently selected feed list node
  *
  * Returns: (transfer none) (nullable): selected node (or NULL)
  */
@@ -136,7 +112,7 @@ typedef enum {
  * @type:		        NODE_BY_(URL|FOLDER_TITLE|ID)
  * @str:		        string to compare to
  *
- * Search trough list of subscriptions for a node matching exactly 
+ * Search trough list of subscriptions for a node matching exactly
  * to an criteria defined by the find type and comparison string.
  * Searches recursively from a given parent node or the root node.
  * Always returns just the first occurence in traversal order.
@@ -156,6 +132,18 @@ nodePtr feedlist_find_node (nodePtr parent, feedListFindType type, const gchar *
  */
 void feedlist_add_subscription (const gchar *source, const gchar *filter, updateOptionsPtr options, gint flags);
 
+/**
+ * feedlist_add_subscription_check_duplicate: (skip)
+ * @source:	        the subscriptions source URL
+ * @filter: (nullable):	NULL or the filter for the subscription
+ * @options: (nullable): NULL or the update options
+ * @flags:		download request flags
+ *
+ * Adds a new subscription to the feed list, if there are no subscriptions with
+ * the same URL, or opens a confirmation dialog else.
+ */
+void feedlist_add_subscription_check_duplicate (const gchar *source, const gchar *filter, updateOptionsPtr options, gint flags);
+
 /**
  * feedlist_add_folder:
  * @title:		the title of the new folder.
@@ -170,11 +158,11 @@ void feedlist_add_folder (const gchar *title);
  *
  * Notifies the feed list controller that a new node
  * was added to the feed list. This method will insert
- * the new node into the feed list view and select 
+ * the new node into the feed list view and select
  * the new node.
  *
  * This method is used for all node types (feeds, folders...).
- * 
+ *
  * Before calling this method the node must be given
  * a parent node using node_set_parent().
  *
@@ -191,7 +179,7 @@ void feedlist_node_added (nodePtr node);
  * selection won't be changed.
  *
  * This method is used for all node types (feeds, folders...).
- * 
+ *
  * Before calling this method the node must be given
  * a parent node using node_set_parent().
  *
@@ -212,7 +200,7 @@ void feedlist_remove_node (nodePtr node);
  *
  * Notifies the feed list controller that an existing
  * node was removed from it's source (feed list subtree)
- * and is to be destroyed and to be removed from the 
+ * and is to be destroyed and to be removed from the
  * feed list view.
  *
  */
@@ -271,22 +259,12 @@ void feedlist_mark_all_read (nodePtr node);
  */
 #define feedlist_foreach_data(func, user_data) node_foreach_child_data(feedlist_get_root(), func, user_data)
 
-/* UI callbacks */
-
 /**
- * feedlist_selection_changed: (skip)
- * @node:	the new selected node
- *
- * Callback for feed list selection change .
- */
-void feedlist_selection_changed (nodePtr node);
-
-/** 
  * feedlist_find_unread_feed: (skip)
  * @folder:	the folder to search
  *
  * Tries to find the first node with an unread item in the given folder.
- * 
+ *
  * Returns: (nullable) (transfer none): a found node or NULL
  */
 nodePtr	feedlist_find_unread_feed (nodePtr folder);
