@@ -2,7 +2,7 @@
  * @file itemlist.c  item list handling
  *
  * Copyright (C) 2004-2012 Lars Windolf <lars.windolf@gmx.de>
- *	      
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -42,11 +42,10 @@
 #include "ui/liferea_shell.h"
 #include "ui/feed_list_view.h"
 #include "ui/liferea_htmlview.h"
-#include "ui/feed_list_node.h"
 
-/* The 'item list' is a controller for 'item view' and database backend. 
+/* The 'item list' is a controller for 'item view' and database backend.
    It manages the currently displayed 'node', realizes filtering
-   by node and 'item set' rules, also duplicate elimination and provides 
+   by node and 'item set' rules, also duplicate elimination and provides
    synchronisation for backend and GUI access to the current itemset.
 
    The 'item list' provides methods to add/remove items from the 'item
@@ -57,7 +56,7 @@
    is done by the 'item view'.
  */
 
-#define ITEMLIST_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), ITEMLIST_TYPE, ItemListPrivate))
+#define ITEMLIST_GET_PRIVATE itemlist_get_instance_private
 
 struct ItemListPrivate
 {
@@ -65,7 +64,7 @@ struct ItemListPrivate
 	itemSetPtr	filter;			/*<< currently active filter rules */
 	nodePtr		currentNode;		/*<< the node whose own or its child items are currently displayed */
 	gulong		selectedId;		/*<< the currently selected (and displayed) item id */
-	
+
 	nodeViewType	viewMode;		/*<< current viewing mode */
 	guint 		loading;		/*<< if >0 prevents selection effects when loading the item list */
 	itemPtr		invalidSelection;	/*<< if set then the next selection might need to do an unselect first */
@@ -77,7 +76,7 @@ struct ItemListPrivate
 static GObjectClass *parent_class = NULL;
 static ItemList *itemlist = NULL;
 
-G_DEFINE_TYPE (ItemList, itemlist, G_TYPE_OBJECT);
+G_DEFINE_TYPE_WITH_CODE (ItemList, itemlist, G_TYPE_OBJECT, G_ADD_PRIVATE (ItemList));
 
 static void
 itemlist_init (ItemList *il)
@@ -143,8 +142,6 @@ itemlist_class_init (ItemListClass *klass)
 	parent_class = g_type_class_peek_parent (klass);
 
 	object_class->finalize = itemlist_finalize;
-
-	g_type_class_add_private (object_class, sizeof(ItemListPrivate));
 }
 
 /* member wrappers */
@@ -170,16 +167,16 @@ itemlist_set_selected (itemPtr item)
 nodePtr
 itemlist_get_displayed_node (void)
 {
-	return itemlist->priv->currentNode; 
+	return itemlist->priv->currentNode;
 }
 
 /* called when unselecting the item or unloading the item list */
 static void
-itemlist_check_for_deferred_action (void) 
+itemlist_check_for_deferred_action (void)
 {
 	gulong	id = itemlist->priv->selectedId;
 	itemPtr	item;
-	
+
 	if (id) {
 		itemlist_set_selected (NULL);
 
@@ -188,7 +185,7 @@ itemlist_check_for_deferred_action (void)
 			itemlist->priv->deferredFilter = FALSE;
 			item = item_load (id);
 			itemview_remove_item (item);
-			feed_list_node_update (item->nodeId);
+			feed_list_view_update_node (item->nodeId);
 		}
 
 		/* check for removals caused by vfolder rules */
@@ -213,20 +210,20 @@ itemlist_filter_check_item (itemPtr item)
 	/* apply the item list filter if available */
 	if (itemlist->priv->filter)
 		return itemset_check_item (itemlist->priv->filter, item);
-	
+
 	/* otherwise keep the item */
 	return TRUE;
 }
 
 static void
-itemlist_merge_item (itemPtr item) 
+itemlist_merge_item (itemPtr item)
 {
 	if (!itemlist_duplicate_list_check_item (item))
-		return;		
-		
+		return;
+
 	if (!itemlist_filter_check_item (item))
 		return;
-		
+
 	itemlist_duplicate_list_add_item (item);
 	itemview_add_item (item);
 }
@@ -243,26 +240,26 @@ itemlist_itemset_is_valid (itemSetPtr itemSet)
 
 	if (!itemlist->priv->currentNode)
 		return FALSE; /* Nothing to do if nothing is displayed */
-		
+
 	if (!IS_VFOLDER (itemlist->priv->currentNode) &&
-	    (itemlist->priv->currentNode != node) && 
+	    (itemlist->priv->currentNode != node) &&
 	    !node_is_ancestor (itemlist->priv->currentNode, node))
 		return FALSE; /* Nothing to do if the item set does not belong to this node, or this is a search folder */
 
 	conf_get_int_value (FOLDER_DISPLAY_MODE, &folder_display_mode);
 	if (IS_FOLDER (itemlist->priv->currentNode) && !folder_display_mode)
 		return FALSE; /* Bail out if it is a folder without the recursive display preference set */
-		
+
 	debug1 (DEBUG_GUI, "reloading item list with node \"%s\"", node_get_title (node));
 
 	return TRUE;
 }
 
 void
-itemlist_merge_itemset (itemSetPtr itemSet) 
+itemlist_merge_itemset (itemSetPtr itemSet)
 {
 	debug_enter ("itemlist_merge_itemset");
-	
+
 	if (itemlist_itemset_is_valid (itemSet)) {
 		debug_start_measurement (DEBUG_GUI);
 		itemset_foreach (itemSet, itemlist_merge_item);
@@ -274,7 +271,7 @@ itemlist_merge_itemset (itemSetPtr itemSet)
 }
 
 void
-itemlist_load (nodePtr node) 
+itemlist_load (nodePtr node)
 {
 	itemSetPtr	itemSet;
 	gint		folder_display_mode;
@@ -283,13 +280,13 @@ itemlist_load (nodePtr node)
 	debug_enter ("itemlist_load");
 
 	g_return_if_fail (NULL != node);
-	
+
 	debug1 (DEBUG_GUI, "loading item list with node \"%s\"", node_get_title (node));
 
 	g_assert (!itemlist->priv->guids);
 	g_assert (!itemlist->priv->filter);
 
-	/* 1. Filter check. Don't continue if folder is selected and 
+	/* 1. Filter check. Don't continue if folder is selected and
 	   no folder viewing is configured. If folder viewing is enabled
 	   set up a "unread items only" rule depending on the prefences. */
 
@@ -300,7 +297,7 @@ itemlist_load (nodePtr node)
 		conf_get_int_value (FOLDER_DISPLAY_MODE, &folder_display_mode);
 		if (!folder_display_mode)
 			return;
-	
+
 		conf_get_bool_value (FOLDER_DISPLAY_HIDE_READ, &folder_display_hide_read);
 		if (folder_display_hide_read) {
 			itemlist->priv->filter = g_new0(struct itemSet, 1);
@@ -323,7 +320,7 @@ itemlist_load (nodePtr node)
 		itemview_set_mode (ITEMVIEW_NODE_INFO);
 	else
 		itemview_set_mode (ITEMVIEW_ALL_ITEMS);
-	
+
 	itemSet = node_get_itemset (itemlist->priv->currentNode);
 	itemlist_merge_itemset (itemSet);
 	if (!IS_VFOLDER (node))			/* FIXME: this is ugly! */
@@ -335,14 +332,14 @@ itemlist_load (nodePtr node)
 }
 
 void
-itemlist_unload (gboolean markRead) 
+itemlist_unload (gboolean markRead)
 {
 	/* Always clear to ensure clearing on search */
 	itemview_clear ();
 
 	if (itemlist->priv->currentNode) {
 		itemview_set_displayed_node (NULL);
-		
+
 		/* 1. Postprocessing for previously selected node, this is necessary
 		   to realize reliable read marking when using condensed mode. It's
 		   important to do this only when the selection really changed. */
@@ -355,13 +352,13 @@ itemlist_unload (gboolean markRead)
 	itemlist_set_selected (NULL);
 	itemlist_duplicate_list_free ();
 	itemlist->priv->currentNode = NULL;
-	
+
 	itemset_free (itemlist->priv->filter);
 	itemlist->priv->filter = NULL;
 }
 
 void
-itemlist_select_next_unread (void) 
+itemlist_select_next_unread (void)
 {
 	itemPtr	result = NULL;
 
@@ -375,10 +372,10 @@ itemlist_select_next_unread (void)
 
 	itemlist->priv->loading++;	/* prevent unwanted selections */
 
-	/* before scanning the feed list, we test if there is a unread 
+	/* before scanning the feed list, we test if there is a unread
 	   item in the currently selected feed! */
 	result = itemview_find_unread_item (itemlist->priv->selectedId);
-	
+
 	/* If none is found we continue searching in the feed list */
 	if (!result) {
 		nodePtr	node;
@@ -398,7 +395,7 @@ itemlist_select_next_unread (void)
 	}
 
 	itemlist->priv->loading--;
-	
+
 	if (result)
 		itemview_select_item (result);
 }
@@ -406,14 +403,14 @@ itemlist_select_next_unread (void)
 /* menu commands */
 
 void
-itemlist_toggle_flag (itemPtr item) 
+itemlist_toggle_flag (itemPtr item)
 {
 	item_set_flag_state (item, !(item->flagStatus));
 	/* No itemview_update() to avoid disturbing HTML scroll state and media content */
 }
 
 void
-itemlist_toggle_read_status (itemPtr item) 
+itemlist_toggle_read_status (itemPtr item)
 {
 	item_set_read_state (item, !(item->readStatus));
 	/* No itemview_update() to avoid disturbing HTML scroll state and media content */
@@ -427,7 +424,7 @@ itemlist_hide_item (itemPtr item)
 	   don't do it and set a flag to do it when unselecting */
 	if (itemlist->priv->selectedId != item->id) {
 		itemview_remove_item (item);
-		feed_list_node_update (item->nodeId);
+		feed_list_view_update_node (item->nodeId);
 	} else {
 		itemlist->priv->deferredFilter = TRUE;
 		/* update the item to show new state that forces
@@ -447,7 +444,7 @@ itemlist_unhide_item (itemPtr item)
 
 /* hard unconditional item remove */
 void
-itemlist_remove_item (itemPtr item) 
+itemlist_remove_item (itemPtr item)
 {
 	if (itemlist->priv->selectedId == item->id) {
 		itemlist_set_selected (NULL);
@@ -456,7 +453,7 @@ itemlist_remove_item (itemPtr item)
 	}
 
 	itemlist_duplicate_list_remove_item (item);
-		
+
 	itemview_remove_item (item);
 	itemview_update ();
 
@@ -465,14 +462,14 @@ itemlist_remove_item (itemPtr item)
 	/* update feed list counters*/
 	vfolder_foreach (node_update_counters);
 	node_update_counters (node_from_id (item->nodeId));
-	
+
 	item_unload (item);
 }
 
 /* soft possibly delayed item remove */
 static void
-itemlist_request_remove_item (itemPtr item) 
-{	
+itemlist_request_remove_item (itemPtr item)
+{
 	/* if the currently selected item should be removed we
 	   don't do it and set a flag to do it when unselecting */
 	if (itemlist->priv->selectedId != item->id) {
@@ -489,7 +486,7 @@ void
 itemlist_remove_items (itemSetPtr itemSet, GList *items)
 {
 	GList		*iter = items;
-	
+
 	while (iter) {
 		itemPtr item = (itemPtr) iter->data;
 
@@ -512,12 +509,12 @@ itemlist_remove_items (itemSetPtr itemSet, GList *items)
 
 void
 itemlist_remove_all_items (nodePtr node)
-{	
+{
 	if (node == itemlist->priv->currentNode)
 		itemview_clear ();
-		
+
 	db_itemset_remove_all (node->id);
-	
+
 	if (node == itemlist->priv->currentNode) {
 		itemview_update ();
 		itemlist_duplicate_list_free ();
@@ -546,7 +543,7 @@ itemlist_update_item (itemPtr item)
 }
 
 /* mouse/keyboard interaction callbacks */
-void 
+void
 itemlist_selection_changed (itemPtr item)
 {
 	debug_enter ("itemlist_selection_changed");
@@ -558,14 +555,14 @@ itemlist_selection_changed (itemPtr item)
 		itemlist_check_for_deferred_action ();
 
 		debug1 (DEBUG_GUI, "item list selection changed to \"%s\"", item?item_get_title (item):"(null)");
-		
+
 		itemlist_set_selected (item);
-	
+
 		/* set read and unset update status when selecting */
 		if (item) {
 			gchar	*link = NULL;
 			nodePtr	node = node_from_id (item->nodeId);
-			
+
 			item_set_read_state (item, TRUE);
 			itemview_set_mode (ITEMVIEW_SINGLE_ITEM);
 
@@ -579,7 +576,7 @@ itemlist_selection_changed (itemPtr item)
 				itemview_select_item (item);
 				itemview_update ();
 			}
-			feed_list_node_update (item->nodeId);
+			feed_list_view_update_node (item->nodeId);
 		}
 
 		feedlist_reset_new_item_count ();
@@ -587,7 +584,7 @@ itemlist_selection_changed (itemPtr item)
 
 	if (item)
 		item_unload (item);
-	
+
 	debug_end_measurement (DEBUG_GUI, "itemlist selection");
 	debug_exit ("itemlist_selection_changed");
 }
@@ -597,7 +594,7 @@ itemlist_selection_changed (itemPtr item)
 guint
 itemlist_get_view_mode (void)
 {
-	return itemlist->priv->viewMode; 
+	return itemlist->priv->viewMode;
 }
 
 void
@@ -659,7 +656,7 @@ itemlist_select_from_history (gboolean back)
 
 	if (back)
 		item = item_history_get_previous ();
-	else 
+	else
 		item = item_history_get_next ();
 
 	if (!item)
@@ -753,4 +750,3 @@ itemlist_create (void)
 {
 	return ITEMLIST (g_object_new (ITEMLIST_TYPE, NULL));
 }
-
