@@ -111,6 +111,14 @@ metadata_init (void)
 	/* for georss:point */
 	metadata_type_register ("point", 		METADATA_TYPE_TEXT);
 
+	/* for mediaRSS */
+	metadata_type_register ("mediadescription", 	METADATA_TYPE_HTML);
+	metadata_type_register ("mediathumbnail", 	METADATA_TYPE_URL);
+	metadata_type_register ("mediastarRatingcount", METADATA_TYPE_TEXT);
+	metadata_type_register ("mediastarRatingavg", 	METADATA_TYPE_TEXT);
+	metadata_type_register ("mediastarRatingmax", 	METADATA_TYPE_TEXT);
+	metadata_type_register ("mediaviews", 		METADATA_TYPE_TEXT);
+
 	return;
 }
 
