@@ -2,7 +2,7 @@
  * @file liferea_shell.c  UI layout handling
  *
  * Copyright (C) 2004-2006 Nathan J. Conrad <t98502@users.sourceforge.net>
- * Copyright (C) 2007-2018 Lars Windolf <lars.windolf@gmx.de>
+ * Copyright (C) 2007-2020 Lars Windolf <lars.windolf@gmx.de>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,6 +26,7 @@
 #include "ui/liferea_shell.h"
 
 #include <gtk/gtk.h>
+#include <gdk/gdkx.h>
 #include <gdk/gdkkeysyms.h>
 #include <libpeas/peas-extension-set.h>
 
@@ -39,6 +40,7 @@
 #include "htmlview.h"
 #include "item_history.h"
 #include "itemlist.h"
+#include "liferea_application.h"
 #include "net_monitor.h"
 #include "newsbin.h"
 #include "plugins_engine.h"
@@ -262,7 +264,7 @@ liferea_shell_restore_position (void)
 
 }
 
-static void
+void
 liferea_shell_save_position (void)
 {
 	GtkWidget	*pane;
@@ -559,7 +561,7 @@ on_notebook_scroll_event_null_cb (GtkWidget *widget, GdkEventScroll *event)
 static gboolean
 on_close (GtkWidget *widget, GdkEvent *event, gpointer user_data)
 {
-	liferea_shutdown ();
+	liferea_application_shutdown ();
 	return TRUE;
 }
 
@@ -771,7 +773,7 @@ on_faq_activate (GSimpleAction *action, GVariant *parameter, gpointer user_data)
 static void
 on_menu_quit (GSimpleAction *action, GVariant *parameter, gpointer user_data)
 {
-	liferea_shutdown ();
+	liferea_application_shutdown ();
 }
 
 static void
@@ -922,7 +924,15 @@ static const GActionEntry liferea_shell_gaction_entries[] = {
 	{"set-view-mode", NULL, "s", "@s 'normal'", on_view_activate},
 	/* Parameter type must be NULL for toggle. */
 	{"fullscreen", NULL, NULL, "@b false", on_menu_fullscreen_activate},
-	{"reduced-feed-list", NULL, NULL, "@b false", on_feedlist_reduced_activate}
+	{"reduced-feed-list", NULL, NULL, "@b false", on_feedlist_reduced_activate},
+
+	{"toggle-item-read-status", on_toggle_unread_status, "t", NULL, NULL},
+	{"toggle-item-flag", on_toggle_item_flag, "t", NULL, NULL},
+	{"remove-item", on_action_remove_item, "t", NULL, NULL},
+	{"launch-item-in-tab", on_action_launch_item_in_tab, "t", NULL, NULL},
+	{"launch-item-in-browser", on_action_launch_item_in_browser, "t", NULL, NULL},
+	{"launch-item-in-external-browser", on_action_launch_item_in_external_browser, "t", NULL, NULL},
+	{"open-item-enclosure", on_action_open_enclosure, "t", NULL, NULL},
 };
 
 static const GActionEntry liferea_shell_add_gaction_entries[] = {
@@ -1350,30 +1360,48 @@ liferea_shell_present (void)
 	gtk_window_present (shell->window);
 }
 
+static gboolean
+liferea_shell_window_is_on_other_desktop(GdkWindow *gdkwindow)
+{
+#ifdef GDK_WINDOWING_X11
+	return GDK_IS_X11_DISPLAY (gdk_window_get_display (gdkwindow)) &&
+	    (gdk_x11_window_get_desktop (gdkwindow) !=
+	     gdk_x11_screen_get_current_desktop (gdk_window_get_screen (gdkwindow)));
+#else
+	return FALSE;
+#endif
+}
+
+static void
+liferea_shell_window_move_to_current_desktop(GdkWindow *gdkwindow)
+{
+#ifdef GDK_WINDOWING_X11
+	if (GDK_IS_X11_DISPLAY (gdk_window_get_display (gdkwindow)))
+	    gdk_x11_window_move_to_current_desktop (gdkwindow);
+#endif
+}
+
+void liferea_shell_show_window (void)
+{
+	GtkWidget *mainwindow = GTK_WIDGET (shell->window);
+	GdkWindow *gdkwindow = gtk_widget_get_window (mainwindow);
+
+	liferea_shell_window_move_to_current_desktop (gdkwindow);
+	if (!gtk_widget_get_visible (GTK_WIDGET (mainwindow)))
+		liferea_shell_restore_position ();
+	gtk_window_deiconify (GTK_WINDOW (mainwindow));
+	gtk_window_present (shell->window);
+}
+
 void
 liferea_shell_toggle_visibility (void)
 {
 	GtkWidget *mainwindow = GTK_WIDGET (shell->window);
+	GdkWindow *gdkwindow = gtk_widget_get_window (mainwindow);
 
-	if (gdk_window_get_state (gtk_widget_get_window (mainwindow)) & GDK_WINDOW_STATE_ICONIFIED) {
-		/* The window is either iconified, or on another workspace */
-		/* Raise it in one click */
-		if (gtk_widget_get_visible (mainwindow)) {
-			liferea_shell_save_position ();
-			gtk_widget_hide (mainwindow);
-		}
-		liferea_shell_restore_position ();
-		/* Note: Without deiconify() desktop moving doesn't work in
-		   GNOME+metacity. The window would be moved correctly by
-		   present() but not become visible. */
-		gtk_window_deiconify (GTK_WINDOW (mainwindow));
-		gtk_window_present (GTK_WINDOW (mainwindow));
-	}
-	else if (!gtk_widget_get_visible (mainwindow)) {
-		/* The window is neither iconified nor on another workspace, but is not visible */
-		liferea_shell_restore_position ();
-		gtk_window_deiconify (GTK_WINDOW (mainwindow));
-		gtk_window_present (shell->window);
+	if (liferea_shell_window_is_on_other_desktop (gdkwindow) ||
+	    !gtk_widget_get_visible (mainwindow)) {
+		liferea_shell_show_window ();
 	} else {
 		liferea_shell_save_position ();
 		gtk_widget_hide (mainwindow);
