@@ -53,6 +53,14 @@ G_DECLARE_FINAL_TYPE (LifereaShell, liferea_shell, LIFEREA, SHELL, GObject)
  */
 GtkWidget * liferea_shell_lookup (const gchar *name);
 
+/**
+ * liferea_shell_save_position
+ *
+ * Save the position of the Liferea main window.
+ */
+void
+liferea_shell_save_position (void);
+
 /**
  * liferea_shell_create: (skip)
  * @app:	                the GtkApplication to attach the main window to
@@ -77,6 +85,13 @@ void liferea_shell_destroy (void);
  */
 void liferea_shell_present (void);
 
+/**
+ * liferea_shell_show_window:
+ *
+ * Show the main window.
+ */
+void liferea_shell_show_window (void);
+
 /**
  * liferea_shell_toggle_visibility:
  *
@@ -178,8 +193,6 @@ void liferea_shell_set_important_status_bar (const char *format, ...);
  */
 GtkWidget * liferea_shell_get_window (void);
 
-void liferea_shutdown (void);
-
 G_END_DECLS
 
 #endif
